def getAlarms(vmanage, deviceId):
    """
    Get hardware alarm list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/alarms?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getEnvironments(vmanage, deviceId):
    """
    Get hardware environment list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/environment?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getErrorAlarms(vmanage):
    """
    Get hardware error list from device
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/errors"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInventory(vmanage, deviceId):
    """
    Get hardware inventory list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/inventory?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatusSummary(vmanage, deviceId):
    """
    Get hardware status summary from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/status/summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncAlarms(vmanage, deviceId):
    """
    Get hardware alarm list synchronously from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/synced/alarms?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncEnvironments(vmanage, deviceId):
    """
    Get hardware environment list synchronously from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/synced/environment?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncInventory(vmanage, deviceId):
    """
    Get hardware inventory list synchronously from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/synced/inventory?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSystem(vmanage, deviceId):
    """
    Get hardware system data list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/system?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTempThreshold(vmanage, deviceId):
    """
    Get hardware temperature list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardware/threshold?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
