from py_viptela.api.config.template import config
from py_viptela.api.config.template import design
from py_viptela.api.config.template import device
from py_viptela.api.config.template import general
from py_viptela.api.config.template import lock
from py_viptela.api.config.template import master
from py_viptela.api.config.template import security
from py_viptela.api.config.template import vedge
from py_viptela.api.config.template import voice
from py_viptela.api.config.template import vsmart